from flask import Blueprint
from flask import redirect
from flask import render_template
from flask import request
from flask_login import current_user
from flask_login import login_required
from sqlalchemy import and_
from sqlalchemy import or_
from sqlalchemy import select

from htmx_contact import Session
from htmx_contact.models import Contact

bp = Blueprint("main", __name__, url_prefix="/")


@bp.route("/", methods=["GET"])
def index():
    return redirect("/contacts")


@bp.route("/contacts", methods=["GET"])
@login_required
def contacts():
    search = request.args.get("q")
    if search is not None:
        stmt = (
            select(Contact)
            .where(
                and_(
                    Contact.user_id == current_user.id,
                    or_(
                        Contact.first_name.like(f"%{search}%"),
                        Contact.last_name.like(f"%{search}%"),
                        Contact.email.like(f"%{search}%"),
                    ),
                )
            )
            .order_by(Contact.last_name, Contact.first_name)
        )
    else:
        stmt = select(Contact).where(Contact.user_id == current_user.id).order_by(Contact.last_name, Contact.first_name)

    with Session() as session:
        results = session.scalars(stmt).all()

    return render_template("contacts.html", contacts=results)
